# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: csr.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='csr.proto',
  package='autocsr',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\tcsr.proto\x12\x07\x61utocsr\"\xd2O\n\x19\x43\x65rtificateSigningRequest\x12;\n\x07subject\x18\x01 \x01(\x0b\x32*.autocsr.CertificateSigningRequest.Subject\x12>\n\x08key_info\x18\x02 \x01(\x0b\x32*.autocsr.CertificateSigningRequest.KeyInfoH\x00\x12>\n\x08hsm_info\x18\x03 \x01(\x0b\x32*.autocsr.CertificateSigningRequest.HsmInfoH\x00\x12\x13\n\x0boutput_path\x18\x04 \x01(\t\x12\x43\n\thash_type\x18\x05 \x01(\x0e\x32+.autocsr.CertificateSigningRequest.HashTypeH\x01\x88\x01\x01\x12@\n\nattributes\x18\x06 \x03(\x0b\x32,.autocsr.CertificateSigningRequest.Attribute\x12@\n\nextensions\x18\x07 \x03(\x0b\x32,.autocsr.CertificateSigningRequest.Extension\x1a\xe0\x02\n\x07Subject\x12\x13\n\x0b\x63ommon_name\x18\x01 \x01(\t\x12\x19\n\x0c\x63ountry_name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12#\n\x16state_or_province_name\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x1a\n\rlocality_name\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x1e\n\x11organization_name\x18\x05 \x01(\tH\x03\x88\x01\x01\x12%\n\x18organizational_unit_name\x18\x06 \x01(\tH\x04\x88\x01\x01\x12\x1a\n\remail_address\x18\x07 \x01(\tH\x05\x88\x01\x01\x42\x0f\n\r_country_nameB\x19\n\x17_state_or_province_nameB\x10\n\x0e_locality_nameB\x14\n\x12_organization_nameB\x1b\n\x19_organizational_unit_nameB\x10\n\x0e_email_address\x1a\xa9\x02\n\x07KeyInfo\x12\x10\n\x08key_path\x18\x01 \x01(\t\x12\x13\n\x06\x63reate\x18\x02 \x01(\x08H\x00\x88\x01\x01\x12\x41\n\x08key_type\x18\x03 \x01(\x0e\x32*.autocsr.CertificateSigningRequest.KeyTypeH\x01\x88\x01\x01\x12\x15\n\x08key_size\x18\x04 \x01(\x05H\x02\x88\x01\x01\x12\x1c\n\x0fpublic_exponent\x18\x05 \x01(\x05H\x03\x88\x01\x01\x12<\n\x05\x63urve\x18\x06 \x01(\x0e\x32(.autocsr.CertificateSigningRequest.CurveH\x04\x88\x01\x01\x42\t\n\x07_createB\x0b\n\t_key_typeB\x0b\n\t_key_sizeB\x12\n\x10_public_exponentB\x08\n\x06_curve\x1aT\n\x07SoftHsm\x12\x13\n\x0btoken_label\x18\x01 \x01(\t\x12\x11\n\tkey_label\x18\x02 \x01(\t\x12\x10\n\x08user_pin\x18\x03 \x01(\t\x12\x0f\n\x07so_file\x18\x04 \x01(\t\x1a\xab\x02\n\x07HsmInfo\x12=\n\x07softhsm\x18\x01 \x01(\x0b\x32*.autocsr.CertificateSigningRequest.SoftHsmH\x00\x12<\n\x08key_type\x18\x02 \x01(\x0e\x32*.autocsr.CertificateSigningRequest.KeyType\x12\x15\n\x08key_size\x18\x03 \x01(\x05H\x01\x88\x01\x01\x12\x1c\n\x0fpublic_exponent\x18\x04 \x01(\x05H\x02\x88\x01\x01\x12<\n\x05\x63urve\x18\x05 \x01(\x0e\x32(.autocsr.CertificateSigningRequest.CurveH\x03\x88\x01\x01\x42\x05\n\x03hsmB\x0b\n\t_key_sizeB\x12\n\x10_public_exponentB\x08\n\x06_curve\x1a+\n\tAttribute\x12\x0b\n\x03oid\x18\x01 \x01(\t\x12\x11\n\tb64_value\x18\x02 \x01(\t\x1a\xaa?\n\tExtension\x12\x10\n\x08\x63ritical\x18\x01 \x01(\x08\x12T\n\x0e\x65xtension_type\x18\x02 \x01(\x0e\x32:.autocsr.CertificateSigningRequest.Extension.ExtensionTypeH\x00\x12L\n\ncrl_number\x18\x03 \x01(\x0b\x32\x36.autocsr.CertificateSigningRequest.Extension.CRLNumberH\x00\x12\x63\n\x16subject_key_identifier\x18\x04 \x01(\x0b\x32\x41.autocsr.CertificateSigningRequest.Extension.SubjectKeyIdentifierH\x00\x12Z\n\x11\x62\x61sic_constraints\x18\x05 \x01(\x0b\x32=.autocsr.CertificateSigningRequest.Extension.BasicConstraintsH\x00\x12]\n\x13\x64\x65lta_crl_indicator\x18\x06 \x01(\x0b\x32>.autocsr.CertificateSigningRequest.Extension.DeltaCRLIndicatorH\x00\x12\\\n\x12policy_constraints\x18\x07 \x01(\x0b\x32>.autocsr.CertificateSigningRequest.Extension.PolicyConstraintsH\x00\x12`\n\x14\x63\x65rtificate_policies\x18\x08 \x01(\x0b\x32@.autocsr.CertificateSigningRequest.Extension.CertificatePoliciesH\x00\x12[\n\x12\x65xtended_key_usage\x18\t \x01(\x0b\x32=.autocsr.CertificateSigningRequest.Extension.ExtendedKeyUsageH\x00\x12N\n\x0btls_feature\x18\n \x01(\x0b\x32\x37.autocsr.CertificateSigningRequest.Extension.TLSFeatureH\x00\x12[\n\x12inhibit_any_policy\x18\x0b \x01(\x0b\x32=.autocsr.CertificateSigningRequest.Extension.InhibitAnyPolicyH\x00\x12J\n\tkey_usage\x18\x0c \x01(\x0b\x32\x35.autocsr.CertificateSigningRequest.Extension.KeyUsageH\x00\x12L\n\ncrl_reason\x18\r \x01(\x0b\x32\x36.autocsr.CertificateSigningRequest.Extension.CRLReasonH\x00\x12V\n\x0finvalidity_date\x18\x0e \x01(\x0b\x32;.autocsr.CertificateSigningRequest.Extension.InvalidityDateH\x00\x12\x8c\x01\n,precertificate_signed_certificate_timestamps\x18\x0f \x01(\x0b\x32T.autocsr.CertificateSigningRequest.Extension.PrecertificateSignedCerticateTimestampsH\x00\x12q\n\x1dsigned_certificate_timestamps\x18\x10 \x01(\x0b\x32H.autocsr.CertificateSigningRequest.Extension.SignedCertificateTimestampsH\x00\x12L\n\nocsp_nonce\x18\x11 \x01(\x0b\x32\x36.autocsr.CertificateSigningRequest.Extension.OCSPNonceH\x00\x12g\n\x18\x61uthority_key_identifier\x18\x12 \x01(\x0b\x32\x43.autocsr.CertificateSigningRequest.Extension.AuthorityKeyIdentifierH\x00\x12o\n\x1c\x61uthority_information_access\x18\x13 \x01(\x0b\x32G.autocsr.CertificateSigningRequest.Extension.AuthorityInformationAccessH\x00\x12k\n\x1asubject_information_access\x18\x14 \x01(\x0b\x32\x45.autocsr.CertificateSigningRequest.Extension.SubjectInformationAccessH\x00\x12\x65\n\x17\x63rl_distribution_points\x18\x15 \x01(\x0b\x32\x42.autocsr.CertificateSigningRequest.Extension.CRLDistributionPointsH\x00\x12P\n\x0c\x66reshest_crl\x18\x16 \x01(\x0b\x32\x38.autocsr.CertificateSigningRequest.Extension.FreshestCRLH\x00\x12X\n\x10name_constraints\x18\x17 \x01(\x0b\x32<.autocsr.CertificateSigningRequest.Extension.NameConstraintsH\x00\x12g\n\x18subject_alternative_name\x18\x18 \x01(\x0b\x32\x43.autocsr.CertificateSigningRequest.Extension.SubjectAlternativeNameH\x00\x12\x65\n\x17issuer_alternative_name\x18\x19 \x01(\x0b\x32\x42.autocsr.CertificateSigningRequest.Extension.IssuerAlternativeNameH\x00\x12\\\n\x12\x63\x65rtificate_issuer\x18\x1a \x01(\x0b\x32>.autocsr.CertificateSigningRequest.Extension.CertificateIssuerH\x00\x12k\n\x1aissuing_distribution_point\x18\x1b \x01(\x0b\x32\x45.autocsr.CertificateSigningRequest.Extension.IssuingDistributionPointH\x00\x1a\x1f\n\tCRLNumber\x12\x12\n\ncrl_number\x18\x01 \x01(\x05\x1a*\n\x14SubjectKeyIdentifier\x12\x12\n\nb64_digest\x18\x01 \x01(\t\x1aH\n\x10\x42\x61sicConstraints\x12\n\n\x02\x63\x61\x18\x01 \x01(\x08\x12\x18\n\x0bpath_length\x18\x02 \x01(\x05H\x00\x88\x01\x01\x42\x0e\n\x0c_path_length\x1a\'\n\x11\x44\x65ltaCRLIndicator\x12\x12\n\ncrl_number\x18\x01 \x01(\x05\x1a\x95\x01\n\x11PolicyConstraints\x12$\n\x17require_explicit_policy\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12#\n\x16inhibit_policy_mapping\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\x1a\n\x18_require_explicit_policyB\x19\n\x17_inhibit_policy_mapping\x1aU\n\x0fNoticeReference\x12\x19\n\x0corganization\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\x0enotice_numbers\x18\x02 \x03(\x05\x42\x0f\n\r_organization\x1a\xac\x01\n\nUserNotice\x12[\n\x10notice_reference\x18\x01 \x01(\x0b\x32<.autocsr.CertificateSigningRequest.Extension.NoticeReferenceH\x00\x88\x01\x01\x12\x1a\n\rexplicit_text\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x13\n\x11_notice_referenceB\x10\n\x0e_explicit_text\x1a\x9b\x01\n\x11PolicyInformation\x12\x19\n\x11policy_identifier\x18\x01 \x01(\t\x12\x19\n\x11string_qualifiers\x18\x02 \x03(\t\x12P\n\x0fuser_qualifiers\x18\x03 \x03(\x0b\x32\x37.autocsr.CertificateSigningRequest.Extension.UserNotice\x1ag\n\x13\x43\x65rtificatePolicies\x12P\n\x08policies\x18\x01 \x03(\x0b\x32>.autocsr.CertificateSigningRequest.Extension.PolicyInformation\x1a\"\n\x10\x45xtendedKeyUsage\x12\x0e\n\x06usages\x18\x01 \x03(\t\x1a[\n\nTLSFeature\x12M\n\x08\x66\x65\x61tures\x18\x01 \x03(\x0e\x32;.autocsr.CertificateSigningRequest.Extension.TLSFeatureType\x1a&\n\x10InhibitAnyPolicy\x12\x12\n\nskip_certs\x18\x01 \x01(\x05\x1a\xe4\x01\n\x08KeyUsage\x12\x19\n\x11\x64igital_signature\x18\x01 \x01(\x08\x12\x1a\n\x12\x63ontent_commitment\x18\x02 \x01(\x08\x12\x18\n\x10key_encipherment\x18\x03 \x01(\x08\x12\x19\n\x11\x64\x61ta_encipherment\x18\x04 \x01(\x08\x12\x15\n\rkey_agreement\x18\x05 \x01(\x08\x12\x15\n\rkey_cert_sign\x18\x06 \x01(\x08\x12\x10\n\x08\x63rl_sign\x18\x07 \x01(\x08\x12\x15\n\rencipher_only\x18\x08 \x01(\x08\x12\x15\n\rdecipher_only\x18\t \x01(\x08\x1aU\n\tCRLReason\x12H\n\x06reason\x18\x01 \x01(\x0e\x32\x38.autocsr.CertificateSigningRequest.Extension.ReasonFlags\x1a)\n\x0eInvalidityDate\x12\x17\n\x0finvalidity_date\x18\x01 \x01(\t\x1a\xdd\x02\n\x1aSignedCertificateTimestamp\x12`\n\x07version\x18\x01 \x01(\x0e\x32O.autocsr.CertificateSigningRequest.Extension.SignedCertificateTimestamp.Version\x12\x12\n\nb64_log_id\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\t\x12h\n\nentry_type\x18\x04 \x01(\x0e\x32T.autocsr.CertificateSigningRequest.Extension.SignedCertificateTimestamp.LogEntryType\"\x11\n\x07Version\x12\x06\n\x02v1\x10\x00\"9\n\x0cLogEntryType\x12\x14\n\x10X509_CERTIFICATE\x10\x00\x12\x13\n\x0fPRE_CERTIFICATE\x10\x01\x1a\x99\x01\n\'PrecertificateSignedCerticateTimestamps\x12n\n\x1dsigned_certificate_timestamps\x18\x01 \x03(\x0b\x32G.autocsr.CertificateSigningRequest.Extension.SignedCertificateTimestamp\x1a\x8d\x01\n\x1bSignedCertificateTimestamps\x12n\n\x1dsigned_certificate_timestamps\x18\x01 \x03(\x0b\x32G.autocsr.CertificateSigningRequest.Extension.SignedCertificateTimestamp\x1a\x1e\n\tOCSPNonce\x12\x11\n\tb64_nonce\x18\x01 \x01(\t\x1a+\n\rNameAttribute\x12\x0b\n\x03oid\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x1aV\n\x04Name\x12N\n\nattributes\x18\x01 \x03(\x0b\x32:.autocsr.CertificateSigningRequest.Extension.NameAttribute\x1a\x1b\n\nRFC822Name\x12\r\n\x05value\x18\x01 \x01(\t\x1a\x18\n\x07\x44NSName\x12\r\n\x05value\x18\x01 \x01(\t\x1a*\n\x19UniformResourceIdentifier\x12\r\n\x05value\x18\x01 \x01(\t\x1aQ\n\rDirectoryName\x12@\n\x05value\x18\x01 \x01(\x0b\x32\x31.autocsr.CertificateSigningRequest.Extension.Name\x1a\x1b\n\x0cRegisteredID\x12\x0b\n\x03oid\x18\x01 \x01(\t\x1a\x1a\n\tIPAddress\x12\r\n\x05value\x18\x01 \x01(\t\x1a+\n\tOtherName\x12\x0b\n\x03oid\x18\x01 \x01(\t\x12\x11\n\tb64_value\x18\x02 \x01(\t\x1a\xe5\x04\n\x0bGeneralName\x12O\n\x0crfc_822_name\x18\x01 \x01(\x0b\x32\x37.autocsr.CertificateSigningRequest.Extension.RFC822NameH\x00\x12H\n\x08\x64ns_name\x18\x02 \x01(\x0b\x32\x34.autocsr.CertificateSigningRequest.Extension.DNSNameH\x00\x12m\n\x1buniform_resource_identifier\x18\x03 \x01(\x0b\x32\x46.autocsr.CertificateSigningRequest.Extension.UniformResourceIdentifierH\x00\x12T\n\x0e\x64irectory_name\x18\x04 \x01(\x0b\x32:.autocsr.CertificateSigningRequest.Extension.DirectoryNameH\x00\x12R\n\rregistered_id\x18\x05 \x01(\x0b\x32\x39.autocsr.CertificateSigningRequest.Extension.RegisteredIDH\x00\x12L\n\nip_address\x18\x06 \x01(\x0b\x32\x36.autocsr.CertificateSigningRequest.Extension.IPAddressH\x00\x12L\n\nother_name\x18\x07 \x01(\x0b\x32\x36.autocsr.CertificateSigningRequest.Extension.OtherNameH\x00\x42\x06\n\x04name\x1a\xed\x01\n\x16\x41uthorityKeyIdentifier\x12\x1b\n\x0ekey_identifier\x18\x01 \x01(\tH\x00\x88\x01\x01\x12W\n\x15\x61uthority_cert_issuer\x18\x02 \x03(\x0b\x32\x38.autocsr.CertificateSigningRequest.Extension.GeneralName\x12)\n\x1c\x61uthority_cert_serial_number\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\x11\n\x0f_key_identifierB\x1f\n\x1d_authority_cert_serial_number\x1a\xbc\x01\n\x0fNameConstraints\x12T\n\x12permitted_subtrees\x18\x01 \x03(\x0b\x32\x38.autocsr.CertificateSigningRequest.Extension.GeneralName\x12S\n\x11\x65xcluded_subtrees\x18\x02 \x03(\x0b\x32\x38.autocsr.CertificateSigningRequest.Extension.GeneralName\x1ai\n\x16SubjectAlternativeName\x12O\n\rgeneral_names\x18\x01 \x03(\x0b\x32\x38.autocsr.CertificateSigningRequest.Extension.GeneralName\x1ah\n\x15IssuerAlternativeName\x12O\n\rgeneral_names\x18\x01 \x03(\x0b\x32\x38.autocsr.CertificateSigningRequest.Extension.GeneralName\x1a\x64\n\x11\x43\x65rtificateIssuer\x12O\n\rgeneral_names\x18\x01 \x03(\x0b\x32\x38.autocsr.CertificateSigningRequest.Extension.GeneralName\x1a}\n\x11\x41\x63\x63\x65ssDescription\x12\x15\n\raccess_method\x18\x01 \x01(\t\x12Q\n\x0f\x61\x63\x63\x65ss_location\x18\x02 \x01(\x0b\x32\x38.autocsr.CertificateSigningRequest.Extension.GeneralName\x1ar\n\x1a\x41uthorityInformationAccess\x12T\n\x0c\x64\x65scriptions\x18\x01 \x03(\x0b\x32>.autocsr.CertificateSigningRequest.Extension.AccessDescription\x1ap\n\x18SubjectInformationAccess\x12T\n\x0c\x64\x65scriptions\x18\x01 \x03(\x0b\x32>.autocsr.CertificateSigningRequest.Extension.AccessDescription\x1a\xda\x02\n\x11\x44istributionPoint\x12K\n\tfull_name\x18\x01 \x03(\x0b\x32\x38.autocsr.CertificateSigningRequest.Extension.GeneralName\x12M\n\rrelative_name\x18\x02 \x01(\x0b\x32\x31.autocsr.CertificateSigningRequest.Extension.NameH\x00\x88\x01\x01\x12I\n\x07reasons\x18\x03 \x03(\x0e\x32\x38.autocsr.CertificateSigningRequest.Extension.ReasonFlags\x12L\n\ncrl_issuer\x18\x04 \x03(\x0b\x32\x38.autocsr.CertificateSigningRequest.Extension.GeneralNameB\x10\n\x0e_relative_name\x1at\n\x15\x43RLDistributionPoints\x12[\n\x13\x64istribution_points\x18\x01 \x03(\x0b\x32>.autocsr.CertificateSigningRequest.Extension.DistributionPoint\x1aj\n\x0b\x46reshestCRL\x12[\n\x13\x64istribution_points\x18\x01 \x03(\x0b\x32>.autocsr.CertificateSigningRequest.Extension.DistributionPoint\x1a\x9c\x03\n\x18IssuingDistributionPoint\x12K\n\tfull_name\x18\x01 \x03(\x0b\x32\x38.autocsr.CertificateSigningRequest.Extension.GeneralName\x12M\n\rrelative_name\x18\x02 \x01(\x0b\x32\x31.autocsr.CertificateSigningRequest.Extension.NameH\x00\x88\x01\x01\x12 \n\x18only_contains_user_certs\x18\x03 \x01(\x08\x12\x1e\n\x16only_contains_ca_certs\x18\x04 \x01(\x08\x12S\n\x11only_some_reasons\x18\x05 \x03(\x0e\x32\x38.autocsr.CertificateSigningRequest.Extension.ReasonFlags\x12\x14\n\x0cindirect_crl\x18\x06 \x01(\x08\x12%\n\x1donly_contains_attribute_certs\x18\x07 \x01(\x08\x42\x10\n\x0e_relative_name\"3\n\rExtensionType\x12\x0f\n\x0bOCSPNoCheck\x10\x00\x12\x11\n\rPrecertPoison\x10\x01\"G\n\x0eTLSFeatureType\x12\n\n\x06unused\x10\x00\x12\x12\n\x0estatus_request\x10\x05\x12\x15\n\x11status_request_v2\x10\x11\"\xe1\x01\n\x0bReasonFlags\x12\x0f\n\x0bunspecified\x10\x00\x12\x12\n\x0ekey_compromise\x10\x01\x12\x11\n\rca_compromise\x10\x02\x12\x17\n\x13\x61\x66\x66iliation_changed\x10\x03\x12\x0e\n\nsuperseded\x10\x04\x12\x1a\n\x16\x63\x65ssation_of_operation\x10\x05\x12\x14\n\x10\x63\x65rtificate_hold\x10\x06\x12\x17\n\x13privilege_withdrawn\x10\x07\x12\x11\n\raa_compromise\x10\x08\x12\x13\n\x0fremove_from_crl\x10\tB\x0b\n\textension\"#\n\x07KeyType\x12\x07\n\x03RSA\x10\x00\x12\x07\n\x03\x44SA\x10\x01\x12\x06\n\x02\x45\x43\x10\x02\"\xa7\x02\n\x05\x43urve\x12\r\n\tSECP256R1\x10\x00\x12\r\n\tSECP384R1\x10\x01\x12\r\n\tSECP521R1\x10\x02\x12\r\n\tSECP192R1\x10\x03\x12\r\n\tSECP256K1\x10\x04\x12\x13\n\x0f\x42rainpoolP256R1\x10\x05\x12\x13\n\x0f\x42rainpoolP384R1\x10\x06\x12\x13\n\x0f\x42rainpoolP512R1\x10\x07\x12\r\n\tSECT571K1\x10\x08\x12\r\n\tSECT409K1\x10\t\x12\r\n\tSECT283K1\x10\n\x12\r\n\tSECT233K1\x10\x0b\x12\r\n\tSECT163K1\x10\x0c\x12\r\n\tSECT571R1\x10\r\x12\r\n\tSECT409R1\x10\x0e\x12\r\n\tSECT283R1\x10\x0f\x12\r\n\tSECT233R1\x10\x10\x12\r\n\tSECT163R2\x10\x11\"\xc8\x01\n\x08HashType\x12\n\n\x06SHA256\x10\x00\x12\n\n\x06SHA224\x10\x01\x12\n\n\x06SHA384\x10\x02\x12\n\n\x06SHA512\x10\x03\x12\x0e\n\nSHA512_224\x10\x04\x12\x0e\n\nSHA512_256\x10\x05\x12\x0b\n\x07\x42LAKE2b\x10\x06\x12\x0b\n\x07\x42LAKE2s\x10\x07\x12\x0c\n\x08SHA3_224\x10\x08\x12\x0c\n\x08SHA3_256\x10\t\x12\x0c\n\x08SHA3_384\x10\n\x12\x0c\n\x08SHA3_512\x10\x0b\x12\x0c\n\x08SHAKE128\x10\x0c\x12\x0c\n\x08SHAKE256\x10\rB\x05\n\x03keyB\x0c\n\n_hash_typeb\x06proto3'
)



_CERTIFICATESIGNINGREQUEST_EXTENSION_SIGNEDCERTIFICATETIMESTAMP_VERSION = _descriptor.EnumDescriptor(
  name='Version',
  full_name='autocsr.CertificateSigningRequest.Extension.SignedCertificateTimestamp.Version',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='v1', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5757,
  serialized_end=5774,
)
_sym_db.RegisterEnumDescriptor(_CERTIFICATESIGNINGREQUEST_EXTENSION_SIGNEDCERTIFICATETIMESTAMP_VERSION)

_CERTIFICATESIGNINGREQUEST_EXTENSION_SIGNEDCERTIFICATETIMESTAMP_LOGENTRYTYPE = _descriptor.EnumDescriptor(
  name='LogEntryType',
  full_name='autocsr.CertificateSigningRequest.Extension.SignedCertificateTimestamp.LogEntryType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='X509_CERTIFICATE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRE_CERTIFICATE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5776,
  serialized_end=5833,
)
_sym_db.RegisterEnumDescriptor(_CERTIFICATESIGNINGREQUEST_EXTENSION_SIGNEDCERTIFICATETIMESTAMP_LOGENTRYTYPE)

_CERTIFICATESIGNINGREQUEST_EXTENSION_EXTENSIONTYPE = _descriptor.EnumDescriptor(
  name='ExtensionType',
  full_name='autocsr.CertificateSigningRequest.Extension.ExtensionType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OCSPNoCheck', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PrecertPoison', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9293,
  serialized_end=9344,
)
_sym_db.RegisterEnumDescriptor(_CERTIFICATESIGNINGREQUEST_EXTENSION_EXTENSIONTYPE)

_CERTIFICATESIGNINGREQUEST_EXTENSION_TLSFEATURETYPE = _descriptor.EnumDescriptor(
  name='TLSFeatureType',
  full_name='autocsr.CertificateSigningRequest.Extension.TLSFeatureType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unused', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='status_request', index=1, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='status_request_v2', index=2, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9346,
  serialized_end=9417,
)
_sym_db.RegisterEnumDescriptor(_CERTIFICATESIGNINGREQUEST_EXTENSION_TLSFEATURETYPE)

_CERTIFICATESIGNINGREQUEST_EXTENSION_REASONFLAGS = _descriptor.EnumDescriptor(
  name='ReasonFlags',
  full_name='autocsr.CertificateSigningRequest.Extension.ReasonFlags',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='key_compromise', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ca_compromise', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='affiliation_changed', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='superseded', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='cessation_of_operation', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='certificate_hold', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='privilege_withdrawn', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='aa_compromise', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='remove_from_crl', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9420,
  serialized_end=9645,
)
_sym_db.RegisterEnumDescriptor(_CERTIFICATESIGNINGREQUEST_EXTENSION_REASONFLAGS)

_CERTIFICATESIGNINGREQUEST_KEYTYPE = _descriptor.EnumDescriptor(
  name='KeyType',
  full_name='autocsr.CertificateSigningRequest.KeyType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RSA', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DSA', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EC', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9660,
  serialized_end=9695,
)
_sym_db.RegisterEnumDescriptor(_CERTIFICATESIGNINGREQUEST_KEYTYPE)

_CERTIFICATESIGNINGREQUEST_CURVE = _descriptor.EnumDescriptor(
  name='Curve',
  full_name='autocsr.CertificateSigningRequest.Curve',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SECP256R1', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SECP384R1', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SECP521R1', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SECP192R1', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SECP256K1', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BrainpoolP256R1', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BrainpoolP384R1', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BrainpoolP512R1', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SECT571K1', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SECT409K1', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SECT283K1', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SECT233K1', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SECT163K1', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SECT571R1', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SECT409R1', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SECT283R1', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SECT233R1', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SECT163R2', index=17, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9698,
  serialized_end=9993,
)
_sym_db.RegisterEnumDescriptor(_CERTIFICATESIGNINGREQUEST_CURVE)

_CERTIFICATESIGNINGREQUEST_HASHTYPE = _descriptor.EnumDescriptor(
  name='HashType',
  full_name='autocsr.CertificateSigningRequest.HashType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SHA256', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHA224', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHA384', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHA512', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHA512_224', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHA512_256', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BLAKE2b', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BLAKE2s', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHA3_224', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHA3_256', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHA3_384', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHA3_512', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHAKE128', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHAKE256', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9996,
  serialized_end=10196,
)
_sym_db.RegisterEnumDescriptor(_CERTIFICATESIGNINGREQUEST_HASHTYPE)


_CERTIFICATESIGNINGREQUEST_SUBJECT = _descriptor.Descriptor(
  name='Subject',
  full_name='autocsr.CertificateSigningRequest.Subject',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='common_name', full_name='autocsr.CertificateSigningRequest.Subject.common_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='country_name', full_name='autocsr.CertificateSigningRequest.Subject.country_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state_or_province_name', full_name='autocsr.CertificateSigningRequest.Subject.state_or_province_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locality_name', full_name='autocsr.CertificateSigningRequest.Subject.locality_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='organization_name', full_name='autocsr.CertificateSigningRequest.Subject.organization_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='organizational_unit_name', full_name='autocsr.CertificateSigningRequest.Subject.organizational_unit_name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='email_address', full_name='autocsr.CertificateSigningRequest.Subject.email_address', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_country_name', full_name='autocsr.CertificateSigningRequest.Subject._country_name',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_state_or_province_name', full_name='autocsr.CertificateSigningRequest.Subject._state_or_province_name',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_locality_name', full_name='autocsr.CertificateSigningRequest.Subject._locality_name',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_organization_name', full_name='autocsr.CertificateSigningRequest.Subject._organization_name',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_organizational_unit_name', full_name='autocsr.CertificateSigningRequest.Subject._organizational_unit_name',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_email_address', full_name='autocsr.CertificateSigningRequest.Subject._email_address',
      index=5, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=464,
  serialized_end=816,
)

_CERTIFICATESIGNINGREQUEST_KEYINFO = _descriptor.Descriptor(
  name='KeyInfo',
  full_name='autocsr.CertificateSigningRequest.KeyInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_path', full_name='autocsr.CertificateSigningRequest.KeyInfo.key_path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create', full_name='autocsr.CertificateSigningRequest.KeyInfo.create', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key_type', full_name='autocsr.CertificateSigningRequest.KeyInfo.key_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key_size', full_name='autocsr.CertificateSigningRequest.KeyInfo.key_size', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='public_exponent', full_name='autocsr.CertificateSigningRequest.KeyInfo.public_exponent', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='curve', full_name='autocsr.CertificateSigningRequest.KeyInfo.curve', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_create', full_name='autocsr.CertificateSigningRequest.KeyInfo._create',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_key_type', full_name='autocsr.CertificateSigningRequest.KeyInfo._key_type',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_key_size', full_name='autocsr.CertificateSigningRequest.KeyInfo._key_size',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_public_exponent', full_name='autocsr.CertificateSigningRequest.KeyInfo._public_exponent',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_curve', full_name='autocsr.CertificateSigningRequest.KeyInfo._curve',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=819,
  serialized_end=1116,
)

_CERTIFICATESIGNINGREQUEST_SOFTHSM = _descriptor.Descriptor(
  name='SoftHsm',
  full_name='autocsr.CertificateSigningRequest.SoftHsm',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token_label', full_name='autocsr.CertificateSigningRequest.SoftHsm.token_label', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key_label', full_name='autocsr.CertificateSigningRequest.SoftHsm.key_label', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_pin', full_name='autocsr.CertificateSigningRequest.SoftHsm.user_pin', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='so_file', full_name='autocsr.CertificateSigningRequest.SoftHsm.so_file', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1118,
  serialized_end=1202,
)

_CERTIFICATESIGNINGREQUEST_HSMINFO = _descriptor.Descriptor(
  name='HsmInfo',
  full_name='autocsr.CertificateSigningRequest.HsmInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='softhsm', full_name='autocsr.CertificateSigningRequest.HsmInfo.softhsm', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key_type', full_name='autocsr.CertificateSigningRequest.HsmInfo.key_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key_size', full_name='autocsr.CertificateSigningRequest.HsmInfo.key_size', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='public_exponent', full_name='autocsr.CertificateSigningRequest.HsmInfo.public_exponent', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='curve', full_name='autocsr.CertificateSigningRequest.HsmInfo.curve', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='hsm', full_name='autocsr.CertificateSigningRequest.HsmInfo.hsm',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_key_size', full_name='autocsr.CertificateSigningRequest.HsmInfo._key_size',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_public_exponent', full_name='autocsr.CertificateSigningRequest.HsmInfo._public_exponent',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_curve', full_name='autocsr.CertificateSigningRequest.HsmInfo._curve',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1205,
  serialized_end=1504,
)

_CERTIFICATESIGNINGREQUEST_ATTRIBUTE = _descriptor.Descriptor(
  name='Attribute',
  full_name='autocsr.CertificateSigningRequest.Attribute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='oid', full_name='autocsr.CertificateSigningRequest.Attribute.oid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='b64_value', full_name='autocsr.CertificateSigningRequest.Attribute.b64_value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1506,
  serialized_end=1549,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_CRLNUMBER = _descriptor.Descriptor(
  name='CRLNumber',
  full_name='autocsr.CertificateSigningRequest.Extension.CRLNumber',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='crl_number', full_name='autocsr.CertificateSigningRequest.Extension.CRLNumber.crl_number', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4084,
  serialized_end=4115,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_SUBJECTKEYIDENTIFIER = _descriptor.Descriptor(
  name='SubjectKeyIdentifier',
  full_name='autocsr.CertificateSigningRequest.Extension.SubjectKeyIdentifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='b64_digest', full_name='autocsr.CertificateSigningRequest.Extension.SubjectKeyIdentifier.b64_digest', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4117,
  serialized_end=4159,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_BASICCONSTRAINTS = _descriptor.Descriptor(
  name='BasicConstraints',
  full_name='autocsr.CertificateSigningRequest.Extension.BasicConstraints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ca', full_name='autocsr.CertificateSigningRequest.Extension.BasicConstraints.ca', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path_length', full_name='autocsr.CertificateSigningRequest.Extension.BasicConstraints.path_length', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_path_length', full_name='autocsr.CertificateSigningRequest.Extension.BasicConstraints._path_length',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4161,
  serialized_end=4233,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_DELTACRLINDICATOR = _descriptor.Descriptor(
  name='DeltaCRLIndicator',
  full_name='autocsr.CertificateSigningRequest.Extension.DeltaCRLIndicator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='crl_number', full_name='autocsr.CertificateSigningRequest.Extension.DeltaCRLIndicator.crl_number', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4235,
  serialized_end=4274,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_POLICYCONSTRAINTS = _descriptor.Descriptor(
  name='PolicyConstraints',
  full_name='autocsr.CertificateSigningRequest.Extension.PolicyConstraints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='require_explicit_policy', full_name='autocsr.CertificateSigningRequest.Extension.PolicyConstraints.require_explicit_policy', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inhibit_policy_mapping', full_name='autocsr.CertificateSigningRequest.Extension.PolicyConstraints.inhibit_policy_mapping', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_require_explicit_policy', full_name='autocsr.CertificateSigningRequest.Extension.PolicyConstraints._require_explicit_policy',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_inhibit_policy_mapping', full_name='autocsr.CertificateSigningRequest.Extension.PolicyConstraints._inhibit_policy_mapping',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4277,
  serialized_end=4426,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_NOTICEREFERENCE = _descriptor.Descriptor(
  name='NoticeReference',
  full_name='autocsr.CertificateSigningRequest.Extension.NoticeReference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='organization', full_name='autocsr.CertificateSigningRequest.Extension.NoticeReference.organization', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notice_numbers', full_name='autocsr.CertificateSigningRequest.Extension.NoticeReference.notice_numbers', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_organization', full_name='autocsr.CertificateSigningRequest.Extension.NoticeReference._organization',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4428,
  serialized_end=4513,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_USERNOTICE = _descriptor.Descriptor(
  name='UserNotice',
  full_name='autocsr.CertificateSigningRequest.Extension.UserNotice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='notice_reference', full_name='autocsr.CertificateSigningRequest.Extension.UserNotice.notice_reference', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='explicit_text', full_name='autocsr.CertificateSigningRequest.Extension.UserNotice.explicit_text', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_notice_reference', full_name='autocsr.CertificateSigningRequest.Extension.UserNotice._notice_reference',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_explicit_text', full_name='autocsr.CertificateSigningRequest.Extension.UserNotice._explicit_text',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4516,
  serialized_end=4688,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_POLICYINFORMATION = _descriptor.Descriptor(
  name='PolicyInformation',
  full_name='autocsr.CertificateSigningRequest.Extension.PolicyInformation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='policy_identifier', full_name='autocsr.CertificateSigningRequest.Extension.PolicyInformation.policy_identifier', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string_qualifiers', full_name='autocsr.CertificateSigningRequest.Extension.PolicyInformation.string_qualifiers', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_qualifiers', full_name='autocsr.CertificateSigningRequest.Extension.PolicyInformation.user_qualifiers', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4691,
  serialized_end=4846,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_CERTIFICATEPOLICIES = _descriptor.Descriptor(
  name='CertificatePolicies',
  full_name='autocsr.CertificateSigningRequest.Extension.CertificatePolicies',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='policies', full_name='autocsr.CertificateSigningRequest.Extension.CertificatePolicies.policies', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4848,
  serialized_end=4951,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_EXTENDEDKEYUSAGE = _descriptor.Descriptor(
  name='ExtendedKeyUsage',
  full_name='autocsr.CertificateSigningRequest.Extension.ExtendedKeyUsage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='usages', full_name='autocsr.CertificateSigningRequest.Extension.ExtendedKeyUsage.usages', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4953,
  serialized_end=4987,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_TLSFEATURE = _descriptor.Descriptor(
  name='TLSFeature',
  full_name='autocsr.CertificateSigningRequest.Extension.TLSFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='features', full_name='autocsr.CertificateSigningRequest.Extension.TLSFeature.features', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4989,
  serialized_end=5080,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_INHIBITANYPOLICY = _descriptor.Descriptor(
  name='InhibitAnyPolicy',
  full_name='autocsr.CertificateSigningRequest.Extension.InhibitAnyPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='skip_certs', full_name='autocsr.CertificateSigningRequest.Extension.InhibitAnyPolicy.skip_certs', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5082,
  serialized_end=5120,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_KEYUSAGE = _descriptor.Descriptor(
  name='KeyUsage',
  full_name='autocsr.CertificateSigningRequest.Extension.KeyUsage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='digital_signature', full_name='autocsr.CertificateSigningRequest.Extension.KeyUsage.digital_signature', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content_commitment', full_name='autocsr.CertificateSigningRequest.Extension.KeyUsage.content_commitment', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key_encipherment', full_name='autocsr.CertificateSigningRequest.Extension.KeyUsage.key_encipherment', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_encipherment', full_name='autocsr.CertificateSigningRequest.Extension.KeyUsage.data_encipherment', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key_agreement', full_name='autocsr.CertificateSigningRequest.Extension.KeyUsage.key_agreement', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key_cert_sign', full_name='autocsr.CertificateSigningRequest.Extension.KeyUsage.key_cert_sign', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crl_sign', full_name='autocsr.CertificateSigningRequest.Extension.KeyUsage.crl_sign', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encipher_only', full_name='autocsr.CertificateSigningRequest.Extension.KeyUsage.encipher_only', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decipher_only', full_name='autocsr.CertificateSigningRequest.Extension.KeyUsage.decipher_only', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5123,
  serialized_end=5351,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_CRLREASON = _descriptor.Descriptor(
  name='CRLReason',
  full_name='autocsr.CertificateSigningRequest.Extension.CRLReason',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reason', full_name='autocsr.CertificateSigningRequest.Extension.CRLReason.reason', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5353,
  serialized_end=5438,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_INVALIDITYDATE = _descriptor.Descriptor(
  name='InvalidityDate',
  full_name='autocsr.CertificateSigningRequest.Extension.InvalidityDate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='invalidity_date', full_name='autocsr.CertificateSigningRequest.Extension.InvalidityDate.invalidity_date', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5440,
  serialized_end=5481,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_SIGNEDCERTIFICATETIMESTAMP = _descriptor.Descriptor(
  name='SignedCertificateTimestamp',
  full_name='autocsr.CertificateSigningRequest.Extension.SignedCertificateTimestamp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='autocsr.CertificateSigningRequest.Extension.SignedCertificateTimestamp.version', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='b64_log_id', full_name='autocsr.CertificateSigningRequest.Extension.SignedCertificateTimestamp.b64_log_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='autocsr.CertificateSigningRequest.Extension.SignedCertificateTimestamp.timestamp', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='entry_type', full_name='autocsr.CertificateSigningRequest.Extension.SignedCertificateTimestamp.entry_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CERTIFICATESIGNINGREQUEST_EXTENSION_SIGNEDCERTIFICATETIMESTAMP_VERSION,
    _CERTIFICATESIGNINGREQUEST_EXTENSION_SIGNEDCERTIFICATETIMESTAMP_LOGENTRYTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5484,
  serialized_end=5833,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_PRECERTIFICATESIGNEDCERTICATETIMESTAMPS = _descriptor.Descriptor(
  name='PrecertificateSignedCerticateTimestamps',
  full_name='autocsr.CertificateSigningRequest.Extension.PrecertificateSignedCerticateTimestamps',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='signed_certificate_timestamps', full_name='autocsr.CertificateSigningRequest.Extension.PrecertificateSignedCerticateTimestamps.signed_certificate_timestamps', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5836,
  serialized_end=5989,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_SIGNEDCERTIFICATETIMESTAMPS = _descriptor.Descriptor(
  name='SignedCertificateTimestamps',
  full_name='autocsr.CertificateSigningRequest.Extension.SignedCertificateTimestamps',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='signed_certificate_timestamps', full_name='autocsr.CertificateSigningRequest.Extension.SignedCertificateTimestamps.signed_certificate_timestamps', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5992,
  serialized_end=6133,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_OCSPNONCE = _descriptor.Descriptor(
  name='OCSPNonce',
  full_name='autocsr.CertificateSigningRequest.Extension.OCSPNonce',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='b64_nonce', full_name='autocsr.CertificateSigningRequest.Extension.OCSPNonce.b64_nonce', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6135,
  serialized_end=6165,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_NAMEATTRIBUTE = _descriptor.Descriptor(
  name='NameAttribute',
  full_name='autocsr.CertificateSigningRequest.Extension.NameAttribute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='oid', full_name='autocsr.CertificateSigningRequest.Extension.NameAttribute.oid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='autocsr.CertificateSigningRequest.Extension.NameAttribute.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6167,
  serialized_end=6210,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_NAME = _descriptor.Descriptor(
  name='Name',
  full_name='autocsr.CertificateSigningRequest.Extension.Name',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='attributes', full_name='autocsr.CertificateSigningRequest.Extension.Name.attributes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6212,
  serialized_end=6298,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_RFC822NAME = _descriptor.Descriptor(
  name='RFC822Name',
  full_name='autocsr.CertificateSigningRequest.Extension.RFC822Name',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='autocsr.CertificateSigningRequest.Extension.RFC822Name.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6300,
  serialized_end=6327,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_DNSNAME = _descriptor.Descriptor(
  name='DNSName',
  full_name='autocsr.CertificateSigningRequest.Extension.DNSName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='autocsr.CertificateSigningRequest.Extension.DNSName.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6329,
  serialized_end=6353,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_UNIFORMRESOURCEIDENTIFIER = _descriptor.Descriptor(
  name='UniformResourceIdentifier',
  full_name='autocsr.CertificateSigningRequest.Extension.UniformResourceIdentifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='autocsr.CertificateSigningRequest.Extension.UniformResourceIdentifier.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6355,
  serialized_end=6397,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_DIRECTORYNAME = _descriptor.Descriptor(
  name='DirectoryName',
  full_name='autocsr.CertificateSigningRequest.Extension.DirectoryName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='autocsr.CertificateSigningRequest.Extension.DirectoryName.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6399,
  serialized_end=6480,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_REGISTEREDID = _descriptor.Descriptor(
  name='RegisteredID',
  full_name='autocsr.CertificateSigningRequest.Extension.RegisteredID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='oid', full_name='autocsr.CertificateSigningRequest.Extension.RegisteredID.oid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6482,
  serialized_end=6509,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_IPADDRESS = _descriptor.Descriptor(
  name='IPAddress',
  full_name='autocsr.CertificateSigningRequest.Extension.IPAddress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='autocsr.CertificateSigningRequest.Extension.IPAddress.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6511,
  serialized_end=6537,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_OTHERNAME = _descriptor.Descriptor(
  name='OtherName',
  full_name='autocsr.CertificateSigningRequest.Extension.OtherName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='oid', full_name='autocsr.CertificateSigningRequest.Extension.OtherName.oid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='b64_value', full_name='autocsr.CertificateSigningRequest.Extension.OtherName.b64_value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6539,
  serialized_end=6582,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME = _descriptor.Descriptor(
  name='GeneralName',
  full_name='autocsr.CertificateSigningRequest.Extension.GeneralName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rfc_822_name', full_name='autocsr.CertificateSigningRequest.Extension.GeneralName.rfc_822_name', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dns_name', full_name='autocsr.CertificateSigningRequest.Extension.GeneralName.dns_name', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uniform_resource_identifier', full_name='autocsr.CertificateSigningRequest.Extension.GeneralName.uniform_resource_identifier', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='directory_name', full_name='autocsr.CertificateSigningRequest.Extension.GeneralName.directory_name', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='registered_id', full_name='autocsr.CertificateSigningRequest.Extension.GeneralName.registered_id', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_address', full_name='autocsr.CertificateSigningRequest.Extension.GeneralName.ip_address', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='other_name', full_name='autocsr.CertificateSigningRequest.Extension.GeneralName.other_name', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='name', full_name='autocsr.CertificateSigningRequest.Extension.GeneralName.name',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=6585,
  serialized_end=7198,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_AUTHORITYKEYIDENTIFIER = _descriptor.Descriptor(
  name='AuthorityKeyIdentifier',
  full_name='autocsr.CertificateSigningRequest.Extension.AuthorityKeyIdentifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_identifier', full_name='autocsr.CertificateSigningRequest.Extension.AuthorityKeyIdentifier.key_identifier', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authority_cert_issuer', full_name='autocsr.CertificateSigningRequest.Extension.AuthorityKeyIdentifier.authority_cert_issuer', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authority_cert_serial_number', full_name='autocsr.CertificateSigningRequest.Extension.AuthorityKeyIdentifier.authority_cert_serial_number', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_key_identifier', full_name='autocsr.CertificateSigningRequest.Extension.AuthorityKeyIdentifier._key_identifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_authority_cert_serial_number', full_name='autocsr.CertificateSigningRequest.Extension.AuthorityKeyIdentifier._authority_cert_serial_number',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=7201,
  serialized_end=7438,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_NAMECONSTRAINTS = _descriptor.Descriptor(
  name='NameConstraints',
  full_name='autocsr.CertificateSigningRequest.Extension.NameConstraints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='permitted_subtrees', full_name='autocsr.CertificateSigningRequest.Extension.NameConstraints.permitted_subtrees', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='excluded_subtrees', full_name='autocsr.CertificateSigningRequest.Extension.NameConstraints.excluded_subtrees', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7441,
  serialized_end=7629,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_SUBJECTALTERNATIVENAME = _descriptor.Descriptor(
  name='SubjectAlternativeName',
  full_name='autocsr.CertificateSigningRequest.Extension.SubjectAlternativeName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='general_names', full_name='autocsr.CertificateSigningRequest.Extension.SubjectAlternativeName.general_names', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7631,
  serialized_end=7736,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_ISSUERALTERNATIVENAME = _descriptor.Descriptor(
  name='IssuerAlternativeName',
  full_name='autocsr.CertificateSigningRequest.Extension.IssuerAlternativeName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='general_names', full_name='autocsr.CertificateSigningRequest.Extension.IssuerAlternativeName.general_names', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7738,
  serialized_end=7842,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_CERTIFICATEISSUER = _descriptor.Descriptor(
  name='CertificateIssuer',
  full_name='autocsr.CertificateSigningRequest.Extension.CertificateIssuer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='general_names', full_name='autocsr.CertificateSigningRequest.Extension.CertificateIssuer.general_names', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7844,
  serialized_end=7944,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_ACCESSDESCRIPTION = _descriptor.Descriptor(
  name='AccessDescription',
  full_name='autocsr.CertificateSigningRequest.Extension.AccessDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_method', full_name='autocsr.CertificateSigningRequest.Extension.AccessDescription.access_method', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='access_location', full_name='autocsr.CertificateSigningRequest.Extension.AccessDescription.access_location', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7946,
  serialized_end=8071,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_AUTHORITYINFORMATIONACCESS = _descriptor.Descriptor(
  name='AuthorityInformationAccess',
  full_name='autocsr.CertificateSigningRequest.Extension.AuthorityInformationAccess',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='descriptions', full_name='autocsr.CertificateSigningRequest.Extension.AuthorityInformationAccess.descriptions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8073,
  serialized_end=8187,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_SUBJECTINFORMATIONACCESS = _descriptor.Descriptor(
  name='SubjectInformationAccess',
  full_name='autocsr.CertificateSigningRequest.Extension.SubjectInformationAccess',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='descriptions', full_name='autocsr.CertificateSigningRequest.Extension.SubjectInformationAccess.descriptions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8189,
  serialized_end=8301,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_DISTRIBUTIONPOINT = _descriptor.Descriptor(
  name='DistributionPoint',
  full_name='autocsr.CertificateSigningRequest.Extension.DistributionPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='full_name', full_name='autocsr.CertificateSigningRequest.Extension.DistributionPoint.full_name', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relative_name', full_name='autocsr.CertificateSigningRequest.Extension.DistributionPoint.relative_name', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reasons', full_name='autocsr.CertificateSigningRequest.Extension.DistributionPoint.reasons', index=2,
      number=3, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crl_issuer', full_name='autocsr.CertificateSigningRequest.Extension.DistributionPoint.crl_issuer', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_relative_name', full_name='autocsr.CertificateSigningRequest.Extension.DistributionPoint._relative_name',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=8304,
  serialized_end=8650,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_CRLDISTRIBUTIONPOINTS = _descriptor.Descriptor(
  name='CRLDistributionPoints',
  full_name='autocsr.CertificateSigningRequest.Extension.CRLDistributionPoints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='distribution_points', full_name='autocsr.CertificateSigningRequest.Extension.CRLDistributionPoints.distribution_points', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8652,
  serialized_end=8768,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_FRESHESTCRL = _descriptor.Descriptor(
  name='FreshestCRL',
  full_name='autocsr.CertificateSigningRequest.Extension.FreshestCRL',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='distribution_points', full_name='autocsr.CertificateSigningRequest.Extension.FreshestCRL.distribution_points', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8770,
  serialized_end=8876,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION_ISSUINGDISTRIBUTIONPOINT = _descriptor.Descriptor(
  name='IssuingDistributionPoint',
  full_name='autocsr.CertificateSigningRequest.Extension.IssuingDistributionPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='full_name', full_name='autocsr.CertificateSigningRequest.Extension.IssuingDistributionPoint.full_name', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relative_name', full_name='autocsr.CertificateSigningRequest.Extension.IssuingDistributionPoint.relative_name', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='only_contains_user_certs', full_name='autocsr.CertificateSigningRequest.Extension.IssuingDistributionPoint.only_contains_user_certs', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='only_contains_ca_certs', full_name='autocsr.CertificateSigningRequest.Extension.IssuingDistributionPoint.only_contains_ca_certs', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='only_some_reasons', full_name='autocsr.CertificateSigningRequest.Extension.IssuingDistributionPoint.only_some_reasons', index=4,
      number=5, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='indirect_crl', full_name='autocsr.CertificateSigningRequest.Extension.IssuingDistributionPoint.indirect_crl', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='only_contains_attribute_certs', full_name='autocsr.CertificateSigningRequest.Extension.IssuingDistributionPoint.only_contains_attribute_certs', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_relative_name', full_name='autocsr.CertificateSigningRequest.Extension.IssuingDistributionPoint._relative_name',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=8879,
  serialized_end=9291,
)

_CERTIFICATESIGNINGREQUEST_EXTENSION = _descriptor.Descriptor(
  name='Extension',
  full_name='autocsr.CertificateSigningRequest.Extension',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='critical', full_name='autocsr.CertificateSigningRequest.Extension.critical', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extension_type', full_name='autocsr.CertificateSigningRequest.Extension.extension_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crl_number', full_name='autocsr.CertificateSigningRequest.Extension.crl_number', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subject_key_identifier', full_name='autocsr.CertificateSigningRequest.Extension.subject_key_identifier', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='basic_constraints', full_name='autocsr.CertificateSigningRequest.Extension.basic_constraints', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delta_crl_indicator', full_name='autocsr.CertificateSigningRequest.Extension.delta_crl_indicator', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='policy_constraints', full_name='autocsr.CertificateSigningRequest.Extension.policy_constraints', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='certificate_policies', full_name='autocsr.CertificateSigningRequest.Extension.certificate_policies', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extended_key_usage', full_name='autocsr.CertificateSigningRequest.Extension.extended_key_usage', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tls_feature', full_name='autocsr.CertificateSigningRequest.Extension.tls_feature', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inhibit_any_policy', full_name='autocsr.CertificateSigningRequest.Extension.inhibit_any_policy', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key_usage', full_name='autocsr.CertificateSigningRequest.Extension.key_usage', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crl_reason', full_name='autocsr.CertificateSigningRequest.Extension.crl_reason', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invalidity_date', full_name='autocsr.CertificateSigningRequest.Extension.invalidity_date', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='precertificate_signed_certificate_timestamps', full_name='autocsr.CertificateSigningRequest.Extension.precertificate_signed_certificate_timestamps', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signed_certificate_timestamps', full_name='autocsr.CertificateSigningRequest.Extension.signed_certificate_timestamps', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ocsp_nonce', full_name='autocsr.CertificateSigningRequest.Extension.ocsp_nonce', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authority_key_identifier', full_name='autocsr.CertificateSigningRequest.Extension.authority_key_identifier', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authority_information_access', full_name='autocsr.CertificateSigningRequest.Extension.authority_information_access', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subject_information_access', full_name='autocsr.CertificateSigningRequest.Extension.subject_information_access', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crl_distribution_points', full_name='autocsr.CertificateSigningRequest.Extension.crl_distribution_points', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='freshest_crl', full_name='autocsr.CertificateSigningRequest.Extension.freshest_crl', index=21,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name_constraints', full_name='autocsr.CertificateSigningRequest.Extension.name_constraints', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subject_alternative_name', full_name='autocsr.CertificateSigningRequest.Extension.subject_alternative_name', index=23,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issuer_alternative_name', full_name='autocsr.CertificateSigningRequest.Extension.issuer_alternative_name', index=24,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='certificate_issuer', full_name='autocsr.CertificateSigningRequest.Extension.certificate_issuer', index=25,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issuing_distribution_point', full_name='autocsr.CertificateSigningRequest.Extension.issuing_distribution_point', index=26,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CERTIFICATESIGNINGREQUEST_EXTENSION_CRLNUMBER, _CERTIFICATESIGNINGREQUEST_EXTENSION_SUBJECTKEYIDENTIFIER, _CERTIFICATESIGNINGREQUEST_EXTENSION_BASICCONSTRAINTS, _CERTIFICATESIGNINGREQUEST_EXTENSION_DELTACRLINDICATOR, _CERTIFICATESIGNINGREQUEST_EXTENSION_POLICYCONSTRAINTS, _CERTIFICATESIGNINGREQUEST_EXTENSION_NOTICEREFERENCE, _CERTIFICATESIGNINGREQUEST_EXTENSION_USERNOTICE, _CERTIFICATESIGNINGREQUEST_EXTENSION_POLICYINFORMATION, _CERTIFICATESIGNINGREQUEST_EXTENSION_CERTIFICATEPOLICIES, _CERTIFICATESIGNINGREQUEST_EXTENSION_EXTENDEDKEYUSAGE, _CERTIFICATESIGNINGREQUEST_EXTENSION_TLSFEATURE, _CERTIFICATESIGNINGREQUEST_EXTENSION_INHIBITANYPOLICY, _CERTIFICATESIGNINGREQUEST_EXTENSION_KEYUSAGE, _CERTIFICATESIGNINGREQUEST_EXTENSION_CRLREASON, _CERTIFICATESIGNINGREQUEST_EXTENSION_INVALIDITYDATE, _CERTIFICATESIGNINGREQUEST_EXTENSION_SIGNEDCERTIFICATETIMESTAMP, _CERTIFICATESIGNINGREQUEST_EXTENSION_PRECERTIFICATESIGNEDCERTICATETIMESTAMPS, _CERTIFICATESIGNINGREQUEST_EXTENSION_SIGNEDCERTIFICATETIMESTAMPS, _CERTIFICATESIGNINGREQUEST_EXTENSION_OCSPNONCE, _CERTIFICATESIGNINGREQUEST_EXTENSION_NAMEATTRIBUTE, _CERTIFICATESIGNINGREQUEST_EXTENSION_NAME, _CERTIFICATESIGNINGREQUEST_EXTENSION_RFC822NAME, _CERTIFICATESIGNINGREQUEST_EXTENSION_DNSNAME, _CERTIFICATESIGNINGREQUEST_EXTENSION_UNIFORMRESOURCEIDENTIFIER, _CERTIFICATESIGNINGREQUEST_EXTENSION_DIRECTORYNAME, _CERTIFICATESIGNINGREQUEST_EXTENSION_REGISTEREDID, _CERTIFICATESIGNINGREQUEST_EXTENSION_IPADDRESS, _CERTIFICATESIGNINGREQUEST_EXTENSION_OTHERNAME, _CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME, _CERTIFICATESIGNINGREQUEST_EXTENSION_AUTHORITYKEYIDENTIFIER, _CERTIFICATESIGNINGREQUEST_EXTENSION_NAMECONSTRAINTS, _CERTIFICATESIGNINGREQUEST_EXTENSION_SUBJECTALTERNATIVENAME, _CERTIFICATESIGNINGREQUEST_EXTENSION_ISSUERALTERNATIVENAME, _CERTIFICATESIGNINGREQUEST_EXTENSION_CERTIFICATEISSUER, _CERTIFICATESIGNINGREQUEST_EXTENSION_ACCESSDESCRIPTION, _CERTIFICATESIGNINGREQUEST_EXTENSION_AUTHORITYINFORMATIONACCESS, _CERTIFICATESIGNINGREQUEST_EXTENSION_SUBJECTINFORMATIONACCESS, _CERTIFICATESIGNINGREQUEST_EXTENSION_DISTRIBUTIONPOINT, _CERTIFICATESIGNINGREQUEST_EXTENSION_CRLDISTRIBUTIONPOINTS, _CERTIFICATESIGNINGREQUEST_EXTENSION_FRESHESTCRL, _CERTIFICATESIGNINGREQUEST_EXTENSION_ISSUINGDISTRIBUTIONPOINT, ],
  enum_types=[
    _CERTIFICATESIGNINGREQUEST_EXTENSION_EXTENSIONTYPE,
    _CERTIFICATESIGNINGREQUEST_EXTENSION_TLSFEATURETYPE,
    _CERTIFICATESIGNINGREQUEST_EXTENSION_REASONFLAGS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='extension', full_name='autocsr.CertificateSigningRequest.Extension.extension',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1552,
  serialized_end=9658,
)

_CERTIFICATESIGNINGREQUEST = _descriptor.Descriptor(
  name='CertificateSigningRequest',
  full_name='autocsr.CertificateSigningRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subject', full_name='autocsr.CertificateSigningRequest.subject', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key_info', full_name='autocsr.CertificateSigningRequest.key_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hsm_info', full_name='autocsr.CertificateSigningRequest.hsm_info', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_path', full_name='autocsr.CertificateSigningRequest.output_path', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hash_type', full_name='autocsr.CertificateSigningRequest.hash_type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='autocsr.CertificateSigningRequest.attributes', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extensions', full_name='autocsr.CertificateSigningRequest.extensions', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CERTIFICATESIGNINGREQUEST_SUBJECT, _CERTIFICATESIGNINGREQUEST_KEYINFO, _CERTIFICATESIGNINGREQUEST_SOFTHSM, _CERTIFICATESIGNINGREQUEST_HSMINFO, _CERTIFICATESIGNINGREQUEST_ATTRIBUTE, _CERTIFICATESIGNINGREQUEST_EXTENSION, ],
  enum_types=[
    _CERTIFICATESIGNINGREQUEST_KEYTYPE,
    _CERTIFICATESIGNINGREQUEST_CURVE,
    _CERTIFICATESIGNINGREQUEST_HASHTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='key', full_name='autocsr.CertificateSigningRequest.key',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_hash_type', full_name='autocsr.CertificateSigningRequest._hash_type',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=23,
  serialized_end=10217,
)

_CERTIFICATESIGNINGREQUEST_SUBJECT.containing_type = _CERTIFICATESIGNINGREQUEST
_CERTIFICATESIGNINGREQUEST_SUBJECT.oneofs_by_name['_country_name'].fields.append(
  _CERTIFICATESIGNINGREQUEST_SUBJECT.fields_by_name['country_name'])
_CERTIFICATESIGNINGREQUEST_SUBJECT.fields_by_name['country_name'].containing_oneof = _CERTIFICATESIGNINGREQUEST_SUBJECT.oneofs_by_name['_country_name']
_CERTIFICATESIGNINGREQUEST_SUBJECT.oneofs_by_name['_state_or_province_name'].fields.append(
  _CERTIFICATESIGNINGREQUEST_SUBJECT.fields_by_name['state_or_province_name'])
_CERTIFICATESIGNINGREQUEST_SUBJECT.fields_by_name['state_or_province_name'].containing_oneof = _CERTIFICATESIGNINGREQUEST_SUBJECT.oneofs_by_name['_state_or_province_name']
_CERTIFICATESIGNINGREQUEST_SUBJECT.oneofs_by_name['_locality_name'].fields.append(
  _CERTIFICATESIGNINGREQUEST_SUBJECT.fields_by_name['locality_name'])
_CERTIFICATESIGNINGREQUEST_SUBJECT.fields_by_name['locality_name'].containing_oneof = _CERTIFICATESIGNINGREQUEST_SUBJECT.oneofs_by_name['_locality_name']
_CERTIFICATESIGNINGREQUEST_SUBJECT.oneofs_by_name['_organization_name'].fields.append(
  _CERTIFICATESIGNINGREQUEST_SUBJECT.fields_by_name['organization_name'])
_CERTIFICATESIGNINGREQUEST_SUBJECT.fields_by_name['organization_name'].containing_oneof = _CERTIFICATESIGNINGREQUEST_SUBJECT.oneofs_by_name['_organization_name']
_CERTIFICATESIGNINGREQUEST_SUBJECT.oneofs_by_name['_organizational_unit_name'].fields.append(
  _CERTIFICATESIGNINGREQUEST_SUBJECT.fields_by_name['organizational_unit_name'])
_CERTIFICATESIGNINGREQUEST_SUBJECT.fields_by_name['organizational_unit_name'].containing_oneof = _CERTIFICATESIGNINGREQUEST_SUBJECT.oneofs_by_name['_organizational_unit_name']
_CERTIFICATESIGNINGREQUEST_SUBJECT.oneofs_by_name['_email_address'].fields.append(
  _CERTIFICATESIGNINGREQUEST_SUBJECT.fields_by_name['email_address'])
_CERTIFICATESIGNINGREQUEST_SUBJECT.fields_by_name['email_address'].containing_oneof = _CERTIFICATESIGNINGREQUEST_SUBJECT.oneofs_by_name['_email_address']
_CERTIFICATESIGNINGREQUEST_KEYINFO.fields_by_name['key_type'].enum_type = _CERTIFICATESIGNINGREQUEST_KEYTYPE
_CERTIFICATESIGNINGREQUEST_KEYINFO.fields_by_name['curve'].enum_type = _CERTIFICATESIGNINGREQUEST_CURVE
_CERTIFICATESIGNINGREQUEST_KEYINFO.containing_type = _CERTIFICATESIGNINGREQUEST
_CERTIFICATESIGNINGREQUEST_KEYINFO.oneofs_by_name['_create'].fields.append(
  _CERTIFICATESIGNINGREQUEST_KEYINFO.fields_by_name['create'])
_CERTIFICATESIGNINGREQUEST_KEYINFO.fields_by_name['create'].containing_oneof = _CERTIFICATESIGNINGREQUEST_KEYINFO.oneofs_by_name['_create']
_CERTIFICATESIGNINGREQUEST_KEYINFO.oneofs_by_name['_key_type'].fields.append(
  _CERTIFICATESIGNINGREQUEST_KEYINFO.fields_by_name['key_type'])
_CERTIFICATESIGNINGREQUEST_KEYINFO.fields_by_name['key_type'].containing_oneof = _CERTIFICATESIGNINGREQUEST_KEYINFO.oneofs_by_name['_key_type']
_CERTIFICATESIGNINGREQUEST_KEYINFO.oneofs_by_name['_key_size'].fields.append(
  _CERTIFICATESIGNINGREQUEST_KEYINFO.fields_by_name['key_size'])
_CERTIFICATESIGNINGREQUEST_KEYINFO.fields_by_name['key_size'].containing_oneof = _CERTIFICATESIGNINGREQUEST_KEYINFO.oneofs_by_name['_key_size']
_CERTIFICATESIGNINGREQUEST_KEYINFO.oneofs_by_name['_public_exponent'].fields.append(
  _CERTIFICATESIGNINGREQUEST_KEYINFO.fields_by_name['public_exponent'])
_CERTIFICATESIGNINGREQUEST_KEYINFO.fields_by_name['public_exponent'].containing_oneof = _CERTIFICATESIGNINGREQUEST_KEYINFO.oneofs_by_name['_public_exponent']
_CERTIFICATESIGNINGREQUEST_KEYINFO.oneofs_by_name['_curve'].fields.append(
  _CERTIFICATESIGNINGREQUEST_KEYINFO.fields_by_name['curve'])
_CERTIFICATESIGNINGREQUEST_KEYINFO.fields_by_name['curve'].containing_oneof = _CERTIFICATESIGNINGREQUEST_KEYINFO.oneofs_by_name['_curve']
_CERTIFICATESIGNINGREQUEST_SOFTHSM.containing_type = _CERTIFICATESIGNINGREQUEST
_CERTIFICATESIGNINGREQUEST_HSMINFO.fields_by_name['softhsm'].message_type = _CERTIFICATESIGNINGREQUEST_SOFTHSM
_CERTIFICATESIGNINGREQUEST_HSMINFO.fields_by_name['key_type'].enum_type = _CERTIFICATESIGNINGREQUEST_KEYTYPE
_CERTIFICATESIGNINGREQUEST_HSMINFO.fields_by_name['curve'].enum_type = _CERTIFICATESIGNINGREQUEST_CURVE
_CERTIFICATESIGNINGREQUEST_HSMINFO.containing_type = _CERTIFICATESIGNINGREQUEST
_CERTIFICATESIGNINGREQUEST_HSMINFO.oneofs_by_name['hsm'].fields.append(
  _CERTIFICATESIGNINGREQUEST_HSMINFO.fields_by_name['softhsm'])
_CERTIFICATESIGNINGREQUEST_HSMINFO.fields_by_name['softhsm'].containing_oneof = _CERTIFICATESIGNINGREQUEST_HSMINFO.oneofs_by_name['hsm']
_CERTIFICATESIGNINGREQUEST_HSMINFO.oneofs_by_name['_key_size'].fields.append(
  _CERTIFICATESIGNINGREQUEST_HSMINFO.fields_by_name['key_size'])
_CERTIFICATESIGNINGREQUEST_HSMINFO.fields_by_name['key_size'].containing_oneof = _CERTIFICATESIGNINGREQUEST_HSMINFO.oneofs_by_name['_key_size']
_CERTIFICATESIGNINGREQUEST_HSMINFO.oneofs_by_name['_public_exponent'].fields.append(
  _CERTIFICATESIGNINGREQUEST_HSMINFO.fields_by_name['public_exponent'])
_CERTIFICATESIGNINGREQUEST_HSMINFO.fields_by_name['public_exponent'].containing_oneof = _CERTIFICATESIGNINGREQUEST_HSMINFO.oneofs_by_name['_public_exponent']
_CERTIFICATESIGNINGREQUEST_HSMINFO.oneofs_by_name['_curve'].fields.append(
  _CERTIFICATESIGNINGREQUEST_HSMINFO.fields_by_name['curve'])
_CERTIFICATESIGNINGREQUEST_HSMINFO.fields_by_name['curve'].containing_oneof = _CERTIFICATESIGNINGREQUEST_HSMINFO.oneofs_by_name['_curve']
_CERTIFICATESIGNINGREQUEST_ATTRIBUTE.containing_type = _CERTIFICATESIGNINGREQUEST
_CERTIFICATESIGNINGREQUEST_EXTENSION_CRLNUMBER.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_SUBJECTKEYIDENTIFIER.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_BASICCONSTRAINTS.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_BASICCONSTRAINTS.oneofs_by_name['_path_length'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION_BASICCONSTRAINTS.fields_by_name['path_length'])
_CERTIFICATESIGNINGREQUEST_EXTENSION_BASICCONSTRAINTS.fields_by_name['path_length'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION_BASICCONSTRAINTS.oneofs_by_name['_path_length']
_CERTIFICATESIGNINGREQUEST_EXTENSION_DELTACRLINDICATOR.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_POLICYCONSTRAINTS.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_POLICYCONSTRAINTS.oneofs_by_name['_require_explicit_policy'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION_POLICYCONSTRAINTS.fields_by_name['require_explicit_policy'])
_CERTIFICATESIGNINGREQUEST_EXTENSION_POLICYCONSTRAINTS.fields_by_name['require_explicit_policy'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION_POLICYCONSTRAINTS.oneofs_by_name['_require_explicit_policy']
_CERTIFICATESIGNINGREQUEST_EXTENSION_POLICYCONSTRAINTS.oneofs_by_name['_inhibit_policy_mapping'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION_POLICYCONSTRAINTS.fields_by_name['inhibit_policy_mapping'])
_CERTIFICATESIGNINGREQUEST_EXTENSION_POLICYCONSTRAINTS.fields_by_name['inhibit_policy_mapping'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION_POLICYCONSTRAINTS.oneofs_by_name['_inhibit_policy_mapping']
_CERTIFICATESIGNINGREQUEST_EXTENSION_NOTICEREFERENCE.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_NOTICEREFERENCE.oneofs_by_name['_organization'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION_NOTICEREFERENCE.fields_by_name['organization'])
_CERTIFICATESIGNINGREQUEST_EXTENSION_NOTICEREFERENCE.fields_by_name['organization'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION_NOTICEREFERENCE.oneofs_by_name['_organization']
_CERTIFICATESIGNINGREQUEST_EXTENSION_USERNOTICE.fields_by_name['notice_reference'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_NOTICEREFERENCE
_CERTIFICATESIGNINGREQUEST_EXTENSION_USERNOTICE.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_USERNOTICE.oneofs_by_name['_notice_reference'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION_USERNOTICE.fields_by_name['notice_reference'])
_CERTIFICATESIGNINGREQUEST_EXTENSION_USERNOTICE.fields_by_name['notice_reference'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION_USERNOTICE.oneofs_by_name['_notice_reference']
_CERTIFICATESIGNINGREQUEST_EXTENSION_USERNOTICE.oneofs_by_name['_explicit_text'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION_USERNOTICE.fields_by_name['explicit_text'])
_CERTIFICATESIGNINGREQUEST_EXTENSION_USERNOTICE.fields_by_name['explicit_text'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION_USERNOTICE.oneofs_by_name['_explicit_text']
_CERTIFICATESIGNINGREQUEST_EXTENSION_POLICYINFORMATION.fields_by_name['user_qualifiers'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_USERNOTICE
_CERTIFICATESIGNINGREQUEST_EXTENSION_POLICYINFORMATION.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_CERTIFICATEPOLICIES.fields_by_name['policies'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_POLICYINFORMATION
_CERTIFICATESIGNINGREQUEST_EXTENSION_CERTIFICATEPOLICIES.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_EXTENDEDKEYUSAGE.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_TLSFEATURE.fields_by_name['features'].enum_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_TLSFEATURETYPE
_CERTIFICATESIGNINGREQUEST_EXTENSION_TLSFEATURE.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_INHIBITANYPOLICY.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_KEYUSAGE.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_CRLREASON.fields_by_name['reason'].enum_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_REASONFLAGS
_CERTIFICATESIGNINGREQUEST_EXTENSION_CRLREASON.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_INVALIDITYDATE.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_SIGNEDCERTIFICATETIMESTAMP.fields_by_name['version'].enum_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_SIGNEDCERTIFICATETIMESTAMP_VERSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_SIGNEDCERTIFICATETIMESTAMP.fields_by_name['entry_type'].enum_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_SIGNEDCERTIFICATETIMESTAMP_LOGENTRYTYPE
_CERTIFICATESIGNINGREQUEST_EXTENSION_SIGNEDCERTIFICATETIMESTAMP.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_SIGNEDCERTIFICATETIMESTAMP_VERSION.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_SIGNEDCERTIFICATETIMESTAMP
_CERTIFICATESIGNINGREQUEST_EXTENSION_SIGNEDCERTIFICATETIMESTAMP_LOGENTRYTYPE.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_SIGNEDCERTIFICATETIMESTAMP
_CERTIFICATESIGNINGREQUEST_EXTENSION_PRECERTIFICATESIGNEDCERTICATETIMESTAMPS.fields_by_name['signed_certificate_timestamps'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_SIGNEDCERTIFICATETIMESTAMP
_CERTIFICATESIGNINGREQUEST_EXTENSION_PRECERTIFICATESIGNEDCERTICATETIMESTAMPS.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_SIGNEDCERTIFICATETIMESTAMPS.fields_by_name['signed_certificate_timestamps'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_SIGNEDCERTIFICATETIMESTAMP
_CERTIFICATESIGNINGREQUEST_EXTENSION_SIGNEDCERTIFICATETIMESTAMPS.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_OCSPNONCE.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_NAMEATTRIBUTE.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_NAME.fields_by_name['attributes'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_NAMEATTRIBUTE
_CERTIFICATESIGNINGREQUEST_EXTENSION_NAME.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_RFC822NAME.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_DNSNAME.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_UNIFORMRESOURCEIDENTIFIER.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_DIRECTORYNAME.fields_by_name['value'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_NAME
_CERTIFICATESIGNINGREQUEST_EXTENSION_DIRECTORYNAME.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_REGISTEREDID.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_IPADDRESS.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_OTHERNAME.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME.fields_by_name['rfc_822_name'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_RFC822NAME
_CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME.fields_by_name['dns_name'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_DNSNAME
_CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME.fields_by_name['uniform_resource_identifier'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_UNIFORMRESOURCEIDENTIFIER
_CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME.fields_by_name['directory_name'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_DIRECTORYNAME
_CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME.fields_by_name['registered_id'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_REGISTEREDID
_CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME.fields_by_name['ip_address'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_IPADDRESS
_CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME.fields_by_name['other_name'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_OTHERNAME
_CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME.oneofs_by_name['name'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME.fields_by_name['rfc_822_name'])
_CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME.fields_by_name['rfc_822_name'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME.oneofs_by_name['name']
_CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME.oneofs_by_name['name'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME.fields_by_name['dns_name'])
_CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME.fields_by_name['dns_name'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME.oneofs_by_name['name']
_CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME.oneofs_by_name['name'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME.fields_by_name['uniform_resource_identifier'])
_CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME.fields_by_name['uniform_resource_identifier'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME.oneofs_by_name['name']
_CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME.oneofs_by_name['name'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME.fields_by_name['directory_name'])
_CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME.fields_by_name['directory_name'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME.oneofs_by_name['name']
_CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME.oneofs_by_name['name'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME.fields_by_name['registered_id'])
_CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME.fields_by_name['registered_id'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME.oneofs_by_name['name']
_CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME.oneofs_by_name['name'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME.fields_by_name['ip_address'])
_CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME.fields_by_name['ip_address'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME.oneofs_by_name['name']
_CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME.oneofs_by_name['name'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME.fields_by_name['other_name'])
_CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME.fields_by_name['other_name'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME.oneofs_by_name['name']
_CERTIFICATESIGNINGREQUEST_EXTENSION_AUTHORITYKEYIDENTIFIER.fields_by_name['authority_cert_issuer'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME
_CERTIFICATESIGNINGREQUEST_EXTENSION_AUTHORITYKEYIDENTIFIER.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_AUTHORITYKEYIDENTIFIER.oneofs_by_name['_key_identifier'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION_AUTHORITYKEYIDENTIFIER.fields_by_name['key_identifier'])
_CERTIFICATESIGNINGREQUEST_EXTENSION_AUTHORITYKEYIDENTIFIER.fields_by_name['key_identifier'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION_AUTHORITYKEYIDENTIFIER.oneofs_by_name['_key_identifier']
_CERTIFICATESIGNINGREQUEST_EXTENSION_AUTHORITYKEYIDENTIFIER.oneofs_by_name['_authority_cert_serial_number'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION_AUTHORITYKEYIDENTIFIER.fields_by_name['authority_cert_serial_number'])
_CERTIFICATESIGNINGREQUEST_EXTENSION_AUTHORITYKEYIDENTIFIER.fields_by_name['authority_cert_serial_number'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION_AUTHORITYKEYIDENTIFIER.oneofs_by_name['_authority_cert_serial_number']
_CERTIFICATESIGNINGREQUEST_EXTENSION_NAMECONSTRAINTS.fields_by_name['permitted_subtrees'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME
_CERTIFICATESIGNINGREQUEST_EXTENSION_NAMECONSTRAINTS.fields_by_name['excluded_subtrees'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME
_CERTIFICATESIGNINGREQUEST_EXTENSION_NAMECONSTRAINTS.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_SUBJECTALTERNATIVENAME.fields_by_name['general_names'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME
_CERTIFICATESIGNINGREQUEST_EXTENSION_SUBJECTALTERNATIVENAME.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_ISSUERALTERNATIVENAME.fields_by_name['general_names'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME
_CERTIFICATESIGNINGREQUEST_EXTENSION_ISSUERALTERNATIVENAME.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_CERTIFICATEISSUER.fields_by_name['general_names'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME
_CERTIFICATESIGNINGREQUEST_EXTENSION_CERTIFICATEISSUER.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_ACCESSDESCRIPTION.fields_by_name['access_location'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME
_CERTIFICATESIGNINGREQUEST_EXTENSION_ACCESSDESCRIPTION.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_AUTHORITYINFORMATIONACCESS.fields_by_name['descriptions'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_ACCESSDESCRIPTION
_CERTIFICATESIGNINGREQUEST_EXTENSION_AUTHORITYINFORMATIONACCESS.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_SUBJECTINFORMATIONACCESS.fields_by_name['descriptions'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_ACCESSDESCRIPTION
_CERTIFICATESIGNINGREQUEST_EXTENSION_SUBJECTINFORMATIONACCESS.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_DISTRIBUTIONPOINT.fields_by_name['full_name'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME
_CERTIFICATESIGNINGREQUEST_EXTENSION_DISTRIBUTIONPOINT.fields_by_name['relative_name'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_NAME
_CERTIFICATESIGNINGREQUEST_EXTENSION_DISTRIBUTIONPOINT.fields_by_name['reasons'].enum_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_REASONFLAGS
_CERTIFICATESIGNINGREQUEST_EXTENSION_DISTRIBUTIONPOINT.fields_by_name['crl_issuer'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME
_CERTIFICATESIGNINGREQUEST_EXTENSION_DISTRIBUTIONPOINT.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_DISTRIBUTIONPOINT.oneofs_by_name['_relative_name'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION_DISTRIBUTIONPOINT.fields_by_name['relative_name'])
_CERTIFICATESIGNINGREQUEST_EXTENSION_DISTRIBUTIONPOINT.fields_by_name['relative_name'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION_DISTRIBUTIONPOINT.oneofs_by_name['_relative_name']
_CERTIFICATESIGNINGREQUEST_EXTENSION_CRLDISTRIBUTIONPOINTS.fields_by_name['distribution_points'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_DISTRIBUTIONPOINT
_CERTIFICATESIGNINGREQUEST_EXTENSION_CRLDISTRIBUTIONPOINTS.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_FRESHESTCRL.fields_by_name['distribution_points'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_DISTRIBUTIONPOINT
_CERTIFICATESIGNINGREQUEST_EXTENSION_FRESHESTCRL.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_ISSUINGDISTRIBUTIONPOINT.fields_by_name['full_name'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME
_CERTIFICATESIGNINGREQUEST_EXTENSION_ISSUINGDISTRIBUTIONPOINT.fields_by_name['relative_name'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_NAME
_CERTIFICATESIGNINGREQUEST_EXTENSION_ISSUINGDISTRIBUTIONPOINT.fields_by_name['only_some_reasons'].enum_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_REASONFLAGS
_CERTIFICATESIGNINGREQUEST_EXTENSION_ISSUINGDISTRIBUTIONPOINT.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_ISSUINGDISTRIBUTIONPOINT.oneofs_by_name['_relative_name'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION_ISSUINGDISTRIBUTIONPOINT.fields_by_name['relative_name'])
_CERTIFICATESIGNINGREQUEST_EXTENSION_ISSUINGDISTRIBUTIONPOINT.fields_by_name['relative_name'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION_ISSUINGDISTRIBUTIONPOINT.oneofs_by_name['_relative_name']
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['extension_type'].enum_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_EXTENSIONTYPE
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['crl_number'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_CRLNUMBER
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['subject_key_identifier'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_SUBJECTKEYIDENTIFIER
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['basic_constraints'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_BASICCONSTRAINTS
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['delta_crl_indicator'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_DELTACRLINDICATOR
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['policy_constraints'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_POLICYCONSTRAINTS
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['certificate_policies'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_CERTIFICATEPOLICIES
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['extended_key_usage'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_EXTENDEDKEYUSAGE
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['tls_feature'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_TLSFEATURE
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['inhibit_any_policy'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_INHIBITANYPOLICY
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['key_usage'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_KEYUSAGE
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['crl_reason'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_CRLREASON
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['invalidity_date'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_INVALIDITYDATE
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['precertificate_signed_certificate_timestamps'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_PRECERTIFICATESIGNEDCERTICATETIMESTAMPS
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['signed_certificate_timestamps'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_SIGNEDCERTIFICATETIMESTAMPS
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['ocsp_nonce'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_OCSPNONCE
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['authority_key_identifier'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_AUTHORITYKEYIDENTIFIER
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['authority_information_access'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_AUTHORITYINFORMATIONACCESS
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['subject_information_access'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_SUBJECTINFORMATIONACCESS
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['crl_distribution_points'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_CRLDISTRIBUTIONPOINTS
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['freshest_crl'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_FRESHESTCRL
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['name_constraints'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_NAMECONSTRAINTS
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['subject_alternative_name'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_SUBJECTALTERNATIVENAME
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['issuer_alternative_name'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_ISSUERALTERNATIVENAME
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['certificate_issuer'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_CERTIFICATEISSUER
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['issuing_distribution_point'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION_ISSUINGDISTRIBUTIONPOINT
_CERTIFICATESIGNINGREQUEST_EXTENSION.containing_type = _CERTIFICATESIGNINGREQUEST
_CERTIFICATESIGNINGREQUEST_EXTENSION_EXTENSIONTYPE.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_TLSFEATURETYPE.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION_REASONFLAGS.containing_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['extension_type'])
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['extension_type'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension']
_CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['crl_number'])
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['crl_number'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension']
_CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['subject_key_identifier'])
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['subject_key_identifier'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension']
_CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['basic_constraints'])
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['basic_constraints'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension']
_CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['delta_crl_indicator'])
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['delta_crl_indicator'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension']
_CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['policy_constraints'])
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['policy_constraints'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension']
_CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['certificate_policies'])
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['certificate_policies'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension']
_CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['extended_key_usage'])
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['extended_key_usage'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension']
_CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['tls_feature'])
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['tls_feature'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension']
_CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['inhibit_any_policy'])
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['inhibit_any_policy'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension']
_CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['key_usage'])
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['key_usage'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension']
_CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['crl_reason'])
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['crl_reason'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension']
_CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['invalidity_date'])
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['invalidity_date'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension']
_CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['precertificate_signed_certificate_timestamps'])
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['precertificate_signed_certificate_timestamps'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension']
_CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['signed_certificate_timestamps'])
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['signed_certificate_timestamps'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension']
_CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['ocsp_nonce'])
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['ocsp_nonce'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension']
_CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['authority_key_identifier'])
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['authority_key_identifier'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension']
_CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['authority_information_access'])
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['authority_information_access'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension']
_CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['subject_information_access'])
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['subject_information_access'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension']
_CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['crl_distribution_points'])
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['crl_distribution_points'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension']
_CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['freshest_crl'])
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['freshest_crl'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension']
_CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['name_constraints'])
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['name_constraints'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension']
_CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['subject_alternative_name'])
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['subject_alternative_name'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension']
_CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['issuer_alternative_name'])
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['issuer_alternative_name'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension']
_CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['certificate_issuer'])
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['certificate_issuer'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension']
_CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension'].fields.append(
  _CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['issuing_distribution_point'])
_CERTIFICATESIGNINGREQUEST_EXTENSION.fields_by_name['issuing_distribution_point'].containing_oneof = _CERTIFICATESIGNINGREQUEST_EXTENSION.oneofs_by_name['extension']
_CERTIFICATESIGNINGREQUEST.fields_by_name['subject'].message_type = _CERTIFICATESIGNINGREQUEST_SUBJECT
_CERTIFICATESIGNINGREQUEST.fields_by_name['key_info'].message_type = _CERTIFICATESIGNINGREQUEST_KEYINFO
_CERTIFICATESIGNINGREQUEST.fields_by_name['hsm_info'].message_type = _CERTIFICATESIGNINGREQUEST_HSMINFO
_CERTIFICATESIGNINGREQUEST.fields_by_name['hash_type'].enum_type = _CERTIFICATESIGNINGREQUEST_HASHTYPE
_CERTIFICATESIGNINGREQUEST.fields_by_name['attributes'].message_type = _CERTIFICATESIGNINGREQUEST_ATTRIBUTE
_CERTIFICATESIGNINGREQUEST.fields_by_name['extensions'].message_type = _CERTIFICATESIGNINGREQUEST_EXTENSION
_CERTIFICATESIGNINGREQUEST_KEYTYPE.containing_type = _CERTIFICATESIGNINGREQUEST
_CERTIFICATESIGNINGREQUEST_CURVE.containing_type = _CERTIFICATESIGNINGREQUEST
_CERTIFICATESIGNINGREQUEST_HASHTYPE.containing_type = _CERTIFICATESIGNINGREQUEST
_CERTIFICATESIGNINGREQUEST.oneofs_by_name['key'].fields.append(
  _CERTIFICATESIGNINGREQUEST.fields_by_name['key_info'])
_CERTIFICATESIGNINGREQUEST.fields_by_name['key_info'].containing_oneof = _CERTIFICATESIGNINGREQUEST.oneofs_by_name['key']
_CERTIFICATESIGNINGREQUEST.oneofs_by_name['key'].fields.append(
  _CERTIFICATESIGNINGREQUEST.fields_by_name['hsm_info'])
_CERTIFICATESIGNINGREQUEST.fields_by_name['hsm_info'].containing_oneof = _CERTIFICATESIGNINGREQUEST.oneofs_by_name['key']
_CERTIFICATESIGNINGREQUEST.oneofs_by_name['_hash_type'].fields.append(
  _CERTIFICATESIGNINGREQUEST.fields_by_name['hash_type'])
_CERTIFICATESIGNINGREQUEST.fields_by_name['hash_type'].containing_oneof = _CERTIFICATESIGNINGREQUEST.oneofs_by_name['_hash_type']
DESCRIPTOR.message_types_by_name['CertificateSigningRequest'] = _CERTIFICATESIGNINGREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CertificateSigningRequest = _reflection.GeneratedProtocolMessageType('CertificateSigningRequest', (_message.Message,), {

  'Subject' : _reflection.GeneratedProtocolMessageType('Subject', (_message.Message,), {
    'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_SUBJECT,
    '__module__' : 'csr_pb2'
    # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Subject)
    })
  ,

  'KeyInfo' : _reflection.GeneratedProtocolMessageType('KeyInfo', (_message.Message,), {
    'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_KEYINFO,
    '__module__' : 'csr_pb2'
    # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.KeyInfo)
    })
  ,

  'SoftHsm' : _reflection.GeneratedProtocolMessageType('SoftHsm', (_message.Message,), {
    'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_SOFTHSM,
    '__module__' : 'csr_pb2'
    # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.SoftHsm)
    })
  ,

  'HsmInfo' : _reflection.GeneratedProtocolMessageType('HsmInfo', (_message.Message,), {
    'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_HSMINFO,
    '__module__' : 'csr_pb2'
    # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.HsmInfo)
    })
  ,

  'Attribute' : _reflection.GeneratedProtocolMessageType('Attribute', (_message.Message,), {
    'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_ATTRIBUTE,
    '__module__' : 'csr_pb2'
    # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Attribute)
    })
  ,

  'Extension' : _reflection.GeneratedProtocolMessageType('Extension', (_message.Message,), {

    'CRLNumber' : _reflection.GeneratedProtocolMessageType('CRLNumber', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_CRLNUMBER,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.CRLNumber)
      })
    ,

    'SubjectKeyIdentifier' : _reflection.GeneratedProtocolMessageType('SubjectKeyIdentifier', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_SUBJECTKEYIDENTIFIER,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.SubjectKeyIdentifier)
      })
    ,

    'BasicConstraints' : _reflection.GeneratedProtocolMessageType('BasicConstraints', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_BASICCONSTRAINTS,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.BasicConstraints)
      })
    ,

    'DeltaCRLIndicator' : _reflection.GeneratedProtocolMessageType('DeltaCRLIndicator', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_DELTACRLINDICATOR,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.DeltaCRLIndicator)
      })
    ,

    'PolicyConstraints' : _reflection.GeneratedProtocolMessageType('PolicyConstraints', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_POLICYCONSTRAINTS,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.PolicyConstraints)
      })
    ,

    'NoticeReference' : _reflection.GeneratedProtocolMessageType('NoticeReference', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_NOTICEREFERENCE,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.NoticeReference)
      })
    ,

    'UserNotice' : _reflection.GeneratedProtocolMessageType('UserNotice', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_USERNOTICE,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.UserNotice)
      })
    ,

    'PolicyInformation' : _reflection.GeneratedProtocolMessageType('PolicyInformation', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_POLICYINFORMATION,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.PolicyInformation)
      })
    ,

    'CertificatePolicies' : _reflection.GeneratedProtocolMessageType('CertificatePolicies', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_CERTIFICATEPOLICIES,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.CertificatePolicies)
      })
    ,

    'ExtendedKeyUsage' : _reflection.GeneratedProtocolMessageType('ExtendedKeyUsage', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_EXTENDEDKEYUSAGE,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.ExtendedKeyUsage)
      })
    ,

    'TLSFeature' : _reflection.GeneratedProtocolMessageType('TLSFeature', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_TLSFEATURE,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.TLSFeature)
      })
    ,

    'InhibitAnyPolicy' : _reflection.GeneratedProtocolMessageType('InhibitAnyPolicy', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_INHIBITANYPOLICY,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.InhibitAnyPolicy)
      })
    ,

    'KeyUsage' : _reflection.GeneratedProtocolMessageType('KeyUsage', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_KEYUSAGE,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.KeyUsage)
      })
    ,

    'CRLReason' : _reflection.GeneratedProtocolMessageType('CRLReason', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_CRLREASON,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.CRLReason)
      })
    ,

    'InvalidityDate' : _reflection.GeneratedProtocolMessageType('InvalidityDate', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_INVALIDITYDATE,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.InvalidityDate)
      })
    ,

    'SignedCertificateTimestamp' : _reflection.GeneratedProtocolMessageType('SignedCertificateTimestamp', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_SIGNEDCERTIFICATETIMESTAMP,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.SignedCertificateTimestamp)
      })
    ,

    'PrecertificateSignedCerticateTimestamps' : _reflection.GeneratedProtocolMessageType('PrecertificateSignedCerticateTimestamps', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_PRECERTIFICATESIGNEDCERTICATETIMESTAMPS,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.PrecertificateSignedCerticateTimestamps)
      })
    ,

    'SignedCertificateTimestamps' : _reflection.GeneratedProtocolMessageType('SignedCertificateTimestamps', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_SIGNEDCERTIFICATETIMESTAMPS,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.SignedCertificateTimestamps)
      })
    ,

    'OCSPNonce' : _reflection.GeneratedProtocolMessageType('OCSPNonce', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_OCSPNONCE,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.OCSPNonce)
      })
    ,

    'NameAttribute' : _reflection.GeneratedProtocolMessageType('NameAttribute', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_NAMEATTRIBUTE,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.NameAttribute)
      })
    ,

    'Name' : _reflection.GeneratedProtocolMessageType('Name', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_NAME,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.Name)
      })
    ,

    'RFC822Name' : _reflection.GeneratedProtocolMessageType('RFC822Name', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_RFC822NAME,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.RFC822Name)
      })
    ,

    'DNSName' : _reflection.GeneratedProtocolMessageType('DNSName', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_DNSNAME,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.DNSName)
      })
    ,

    'UniformResourceIdentifier' : _reflection.GeneratedProtocolMessageType('UniformResourceIdentifier', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_UNIFORMRESOURCEIDENTIFIER,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.UniformResourceIdentifier)
      })
    ,

    'DirectoryName' : _reflection.GeneratedProtocolMessageType('DirectoryName', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_DIRECTORYNAME,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.DirectoryName)
      })
    ,

    'RegisteredID' : _reflection.GeneratedProtocolMessageType('RegisteredID', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_REGISTEREDID,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.RegisteredID)
      })
    ,

    'IPAddress' : _reflection.GeneratedProtocolMessageType('IPAddress', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_IPADDRESS,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.IPAddress)
      })
    ,

    'OtherName' : _reflection.GeneratedProtocolMessageType('OtherName', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_OTHERNAME,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.OtherName)
      })
    ,

    'GeneralName' : _reflection.GeneratedProtocolMessageType('GeneralName', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_GENERALNAME,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.GeneralName)
      })
    ,

    'AuthorityKeyIdentifier' : _reflection.GeneratedProtocolMessageType('AuthorityKeyIdentifier', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_AUTHORITYKEYIDENTIFIER,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.AuthorityKeyIdentifier)
      })
    ,

    'NameConstraints' : _reflection.GeneratedProtocolMessageType('NameConstraints', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_NAMECONSTRAINTS,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.NameConstraints)
      })
    ,

    'SubjectAlternativeName' : _reflection.GeneratedProtocolMessageType('SubjectAlternativeName', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_SUBJECTALTERNATIVENAME,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.SubjectAlternativeName)
      })
    ,

    'IssuerAlternativeName' : _reflection.GeneratedProtocolMessageType('IssuerAlternativeName', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_ISSUERALTERNATIVENAME,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.IssuerAlternativeName)
      })
    ,

    'CertificateIssuer' : _reflection.GeneratedProtocolMessageType('CertificateIssuer', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_CERTIFICATEISSUER,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.CertificateIssuer)
      })
    ,

    'AccessDescription' : _reflection.GeneratedProtocolMessageType('AccessDescription', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_ACCESSDESCRIPTION,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.AccessDescription)
      })
    ,

    'AuthorityInformationAccess' : _reflection.GeneratedProtocolMessageType('AuthorityInformationAccess', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_AUTHORITYINFORMATIONACCESS,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.AuthorityInformationAccess)
      })
    ,

    'SubjectInformationAccess' : _reflection.GeneratedProtocolMessageType('SubjectInformationAccess', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_SUBJECTINFORMATIONACCESS,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.SubjectInformationAccess)
      })
    ,

    'DistributionPoint' : _reflection.GeneratedProtocolMessageType('DistributionPoint', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_DISTRIBUTIONPOINT,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.DistributionPoint)
      })
    ,

    'CRLDistributionPoints' : _reflection.GeneratedProtocolMessageType('CRLDistributionPoints', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_CRLDISTRIBUTIONPOINTS,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.CRLDistributionPoints)
      })
    ,

    'FreshestCRL' : _reflection.GeneratedProtocolMessageType('FreshestCRL', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_FRESHESTCRL,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.FreshestCRL)
      })
    ,

    'IssuingDistributionPoint' : _reflection.GeneratedProtocolMessageType('IssuingDistributionPoint', (_message.Message,), {
      'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION_ISSUINGDISTRIBUTIONPOINT,
      '__module__' : 'csr_pb2'
      # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension.IssuingDistributionPoint)
      })
    ,
    'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST_EXTENSION,
    '__module__' : 'csr_pb2'
    # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest.Extension)
    })
  ,
  'DESCRIPTOR' : _CERTIFICATESIGNINGREQUEST,
  '__module__' : 'csr_pb2'
  # @@protoc_insertion_point(class_scope:autocsr.CertificateSigningRequest)
  })
_sym_db.RegisterMessage(CertificateSigningRequest)
_sym_db.RegisterMessage(CertificateSigningRequest.Subject)
_sym_db.RegisterMessage(CertificateSigningRequest.KeyInfo)
_sym_db.RegisterMessage(CertificateSigningRequest.SoftHsm)
_sym_db.RegisterMessage(CertificateSigningRequest.HsmInfo)
_sym_db.RegisterMessage(CertificateSigningRequest.Attribute)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.CRLNumber)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.SubjectKeyIdentifier)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.BasicConstraints)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.DeltaCRLIndicator)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.PolicyConstraints)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.NoticeReference)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.UserNotice)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.PolicyInformation)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.CertificatePolicies)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.ExtendedKeyUsage)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.TLSFeature)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.InhibitAnyPolicy)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.KeyUsage)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.CRLReason)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.InvalidityDate)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.SignedCertificateTimestamp)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.PrecertificateSignedCerticateTimestamps)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.SignedCertificateTimestamps)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.OCSPNonce)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.NameAttribute)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.Name)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.RFC822Name)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.DNSName)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.UniformResourceIdentifier)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.DirectoryName)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.RegisteredID)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.IPAddress)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.OtherName)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.GeneralName)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.AuthorityKeyIdentifier)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.NameConstraints)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.SubjectAlternativeName)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.IssuerAlternativeName)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.CertificateIssuer)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.AccessDescription)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.AuthorityInformationAccess)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.SubjectInformationAccess)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.DistributionPoint)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.CRLDistributionPoints)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.FreshestCRL)
_sym_db.RegisterMessage(CertificateSigningRequest.Extension.IssuingDistributionPoint)


# @@protoc_insertion_point(module_scope)
